==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/es.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrar parámetros mesa de luz gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "director del Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Ancho");
define('MANAGE_GALLERY_FULL_HEIGHT', "Ampliar imágen Altura");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ancho de la imagen en miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Imagen en miniatura Altura");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Pulgar preservar la relación de aspecto");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostrar títulos");
define('MANAGE_GALLERY_DISABLE_SORT', "Desactivar Ordenar");
define('MANAGE_GALLERY_DELETE_IMAGE', "Eliminar Imagen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Guardar el orden de clasificación");
define('MANAGE_GALLERY_PUBLISH_MSG', "Haga clic en &quot;Actualizar&quot; para publicar <br /> imágenes cargadas.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Todas las imágenes han sido redimensionada y configuración se ha guardado.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Hubo un error al cambiar el tamaño de las imágenes o guardar la configuración.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Su imagen (s) se ha cargado.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Se ha producido un error al subir la imagen (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "El archivo que está intentando cargar no es una imagen.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "El archivo que está tratando de subir es demasiado grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "El título se ha guardado.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "¿Seguro que quiere borrar la imagen");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "La imagen ha sido borrada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Se ha producido un error al eliminar la imagen.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Memorización de los parámetros y cambiar el tamaño de las imágenes, por favor espere ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Cargando ... Por favor espere...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "El orden de clasificación no se ha guardado. ¿Quieres guardar el orden de clasificación?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "El orden de las imágenes especie se ha guardado.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Se ha producido un error al guardar el tipo de imagen.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/es.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Administrar parámetros mesa de luz gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "director del Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Ancho");
define('MANAGE_GALLERY_FULL_HEIGHT', "Ampliar imágen Altura");
define('MANAGE_GALLERY_THUMB_WIDTH', "Ancho de la imagen en miniatura");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Imagen en miniatura Altura");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Pulgar preservar la relación de aspecto");
define('MANAGE_GALLERY_SHOW_TITLES', "Mostrar títulos");
define('MANAGE_GALLERY_DISABLE_SORT', "Desactivar Ordenar");
define('MANAGE_GALLERY_DELETE_IMAGE', "Eliminar Imagen");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Guardar el orden de clasificación");
define('MANAGE_GALLERY_PUBLISH_MSG', "Haga clic en &quot;Actualizar&quot; para publicar <br /> imágenes cargadas.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Todas las imágenes han sido redimensionada y configuración se ha guardado.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Hubo un error al cambiar el tamaño de las imágenes o guardar la configuración.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Su imagen (s) se ha cargado.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Se ha producido un error al subir la imagen (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "El archivo que está intentando cargar no es una imagen.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "El archivo que está tratando de subir es demasiado grande.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "El título se ha guardado.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "¿Seguro que quiere borrar la imagen");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "La imagen ha sido borrada.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Se ha producido un error al eliminar la imagen.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Memorización de los parámetros y cambiar el tamaño de las imágenes, por favor espere ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Cargando ... Por favor espere...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "El orden de clasificación no se ha guardado. ¿Quieres guardar el orden de clasificación?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "El orden de las imágenes especie se ha guardado.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Se ha producido un error al guardar el tipo de imagen.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "El archivo que está intentando cargar es más grande que la configuración de PHP &#39;upload_max_filesize&#39; o &#39;post_max_size&#39;. Póngase en contacto con el administrador del sistema para aumentar estos límites.");
?>
